@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2010 by Daniel Nicoletti                                *
+ *   Copyright (C) 2010-2018 by Daniel Nicoletti                           *
  *   dantti12@gmail.com                                                    *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -37,8 +37,7 @@ ModifyPrinter::ModifyPrinter(const QString &destName, bool isClass, QWidget *par
     PrinterPage(parent),
     ui(new Ui::ModifyPrinter),
     m_destName(destName),
-    m_isClass(isClass),
-    m_changes(0)
+    m_isClass(isClass)
 {
     ui->setupUi(this);
 
@@ -54,14 +53,11 @@ ModifyPrinter::ModifyPrinter(const QString &destName, bool isClass, QWidget *par
         ui->membersLV->setPrinter(destName);
     }
 
-    connect(ui->descriptionLE, SIGNAL(textChanged(QString)),
-            this, SLOT(textChanged(QString)));
-    connect(ui->locationLE, SIGNAL(textChanged(QString)),
-            this, SLOT(textChanged(QString)));
-    connect(ui->connectionLE, SIGNAL(textChanged(QString)),
-            this, SLOT(textChanged(QString)));
-    connect(ui->membersLV, SIGNAL(changed(bool)),
-            this, SLOT(modelChanged()));
+    connect(ui->descriptionLE, &QLineEdit::textChanged, this, &ModifyPrinter::textChanged);
+    connect(ui->locationLE, &QLineEdit::textChanged, this, &ModifyPrinter::textChanged);
+    connect(ui->connectionLE, &QLineEdit::textChanged, this, &ModifyPrinter::textChanged);
+    connect(ui->membersLV, static_cast<void(ClassListWidget::*)(bool)>(&ClassListWidget::changed),
+            this, &ModifyPrinter::modelChanged);
 }
 
 ModifyPrinter::~ModifyPrinter()
@@ -73,19 +69,19 @@ void ModifyPrinter::on_makeCB_activated(int index)
 {
     bool isDifferent = true;
     if (ui->makeCB->itemData(index).toUInt() == PPDList) {
-        SelectMakeModelDialog * dialog = new SelectMakeModelDialog(m_make, m_makeAndModel, this);
+        auto dialog = new SelectMakeModelDialog(m_make, m_makeAndModel, this);
         connect(dialog, &SelectMakeModelDialog::accepted, this, &ModifyPrinter::ppdSelectionAccepted);
         connect(dialog, &SelectMakeModelDialog::rejected, this, &ModifyPrinter::ppdSelectionRejected);
         dialog->show();
         return;
     } else if (ui->makeCB->itemData(index).toUInt() == PPDFile) {
         // set the QVariant type to bool makes it possible to know a file was selected
-        m_changedValues["ppd-name"] = true;
+        m_changedValues[QLatin1String("ppd-name")] = true;
     } else if (ui->makeCB->itemData(index).toUInt() == PPDDefault) {
         isDifferent = false;
-        m_changedValues.remove("ppd-name");
+        m_changedValues.remove(QLatin1String("ppd-name"));
     } else if (ui->makeCB->itemData(index).toUInt() == PPDCustom) {
-        m_changedValues["ppd-name"] = ui->makeCB->itemData(index, PPDName).toString();
+        m_changedValues[QLatin1String("ppd-name")] = ui->makeCB->itemData(index, PPDName).toString();
     } else {
         qCWarning(PM_CONFIGURE_PRINTER) << "This should not happen";
         return;
@@ -103,8 +99,8 @@ void ModifyPrinter::on_makeCB_activated(int index)
 
 void ModifyPrinter::ppdSelectionAccepted()
 {
-    SelectMakeModelDialog *dialog = qobject_cast<SelectMakeModelDialog*>(sender());
-    SelectMakeModel *widget = qobject_cast<SelectMakeModel*>(dialog->mainWidget());
+    auto dialog = qobject_cast<SelectMakeModelDialog*>(sender());
+    auto widget = qobject_cast<SelectMakeModel*>(dialog->mainWidget());
 
     if (widget->isFileSelected()) {
         QString fileName = widget->selectedPPDFileName();
@@ -127,7 +123,7 @@ void ModifyPrinter::ppdSelectionAccepted()
 
 void ModifyPrinter::ppdSelectionRejected()
 {
-    SelectMakeModelDialog *dialog = qobject_cast<SelectMakeModelDialog*>(sender());
+    auto dialog = qobject_cast<SelectMakeModelDialog*>(sender());
     ui->makeCB->setCurrentIndex(ui->makeCB->property("lastIndex").toInt());
     dialog->deleteLater();
 }
@@ -189,7 +185,7 @@ void ModifyPrinter::modelChanged()
 
 void ModifyPrinter::textChanged(const QString &text)
 {
-    QLineEdit *le = qobject_cast<QLineEdit *>(sender());
+    auto le = qobject_cast<QLineEdit *>(sender());
 
     bool isDifferent = le->property("orig_text") != text;
     if (isDifferent != le->property("different").toBool()) {
@@ -215,11 +211,11 @@ void ModifyPrinter::save()
         QVariantHash args = m_changedValues;
         QString fileName;
         qCDebug(PM_CONFIGURE_PRINTER) << args;
-        if (args.contains("ppd-name") &&
-            args["ppd-name"].type() == QVariant::Bool) {
+        if (args.contains(QLatin1String("ppd-name")) &&
+            args[QLatin1String("ppd-name")].type() == QVariant::Bool) {
 
             fileName = ui->makeCB->itemData(ui->makeCB->currentIndex(), PPDFile).toString();
-            args.remove("ppd-name");
+            args.remove(QLatin1String("ppd-name"));
         }
         qCDebug(PM_CONFIGURE_PRINTER) << fileName;
 
@@ -232,7 +228,7 @@ void ModifyPrinter::save()
         request->waitTillFinished();
         if (request) {
             if (!request->hasError()) {
-                if (m_changedValues.contains("ppd-name")) {
+                if (m_changedValues.contains(QLatin1String("ppd-name"))) {
                     emit ppdChanged();
                 }
                 request->getPrinterAttributes(m_destName, m_isClass, neededValues());
@@ -284,9 +280,10 @@ void ModifyPrinter::setCurrentMakeAndModel(const QString &makeAndModel)
 
 QStringList ModifyPrinter::neededValues() const
 {
-    QStringList ret;
-    ret << KCUPS_PRINTER_INFO;
-    ret << KCUPS_PRINTER_LOCATION;
+    QStringList ret({
+                        KCUPS_PRINTER_INFO,
+                        KCUPS_PRINTER_LOCATION
+                    });
 
     if (m_isClass) {
         ret << KCUPS_MEMBER_NAMES;
@@ -296,3 +293,5 @@ QStringList ModifyPrinter::neededValues() const
     }
     return ret;
 }
+
+#include "moc_ModifyPrinter.cpp"
